



pip check
IF %ERRORLEVEL% NEQ 0 exit /B 1
jupytext --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %PREFIX%\\share\\jupyter\\labextensions\\jupyterlab-jupytext\\package.json (exit 0) else (exit 1)
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
